@@ -35,8 +35,26 @@ wxBrush AColor::soloBrush;
 wxBrush AColor::envelopeBrush;
 wxPen AColor::envelopePen;
 wxPen AColor::WideEnvelopePen;
+
+wxBrush AColor::labelFlagBrush;
+wxBrush AColor::labelUnselectedBrush;
+wxBrush AColor::labelSelectedBrush;
+wxPen AColor::labelFlagPen;
+wxPen AColor::labelUnselectedPen;
+wxPen AColor::labelSelectedPen;
+
 wxBrush AColor::tooltipBrush;
 
+wxFont AColor::labelFont;
+
+void AColor::SetLabelFont(wxDC & dc)
+{
+  if (!inited)
+    Init(&dc);
+  
+  dc.SetFont(labelFont);
+}
+
 void AColor::Bevel(wxDC & dc, bool up, wxRect & r)
 {
    if (up)
@@ -59,7 +77,7 @@ void AColor::Bevel(wxDC & dc, bool up, wxRect & r)
 void AColor::Light(wxDC * dc, bool selected)
 {
    if (!inited)
-      Init();
+      Init(dc);
    int index = (int) selected;
    dc->SetBrush(lightBrush[index]);
    dc->SetPen(lightPen[index]);
@@ -68,7 +86,7 @@ void AColor::Light(wxDC * dc, bool selected)
 void AColor::Medium(wxDC * dc, bool selected)
 {
    if (!inited)
-      Init();
+      Init(dc);
    int index = (int) selected;
    dc->SetBrush(mediumBrush[index]);
    dc->SetPen(mediumPen[index]);
@@ -77,7 +95,7 @@ void AColor::Medium(wxDC * dc, bool selected)
 void AColor::Dark(wxDC * dc, bool selected)
 {
    if (!inited)
-      Init();
+      Init(dc);
    int index = (int) selected;
    dc->SetBrush(darkBrush[index]);
    dc->SetPen(darkPen[index]);
@@ -86,7 +104,7 @@ void AColor::Dark(wxDC * dc, bool selected)
 void AColor::CursorColor(wxDC * dc)
 {
    if (!inited)
-      Init();
+      Init(dc);
    dc->SetLogicalFunction(wxINVERT);
    dc->SetPen(cursorPen);
 }
@@ -94,7 +112,7 @@ void AColor::CursorColor(wxDC * dc)
 void AColor::IndicatorColor(wxDC * dc, bool recording)
 {
    if (!inited)
-      Init();
+      Init(dc);
    int index = (int) recording;
    dc->SetPen(indicatorPen[index]);
    dc->SetBrush(indicatorBrush[index]);
@@ -103,7 +121,7 @@ void AColor::IndicatorColor(wxDC * dc, bool recording)
 void AColor::Mute(wxDC * dc, bool on, bool selected, bool soloing)
 {
    if (!inited)
-      Init();
+      Init(dc);
    int index = (int) selected;
    if (on) {
       dc->SetPen(*wxBLACK_PEN);
@@ -118,7 +136,7 @@ void AColor::Mute(wxDC * dc, bool on, bool selected, bool soloing)
 void AColor::Solo(wxDC * dc, bool on, bool selected)
 {
    if (!inited)
-      Init();
+      Init(dc);
    int index = (int) selected;
    if (on) {
       dc->SetPen(*wxBLACK_PEN);
@@ -130,11 +148,36 @@ void AColor::Solo(wxDC * dc, bool on, bool selected)
    }
 }
 
-void AColor::Init()
+void AColor::Init(wxDC * dc)
 {
    if (inited)
       return;
 
+   int fontSize = 4;
+   wxCoord strW, strH;
+   wxString exampleText = wxT("Mute");
+   int desiredPixelHeight = 16;
+
+   #ifdef __WXMAC__
+   desiredPixelHeight -= 3;
+   #endif
+   
+   #ifdef __WXMSW__
+   desiredPixelHeight -= 2;
+   #endif
+   
+   // Keep making the font bigger until it's too big, then subtract one.
+   dc->SetFont(wxFont(fontSize, wxSWISS, wxNORMAL, wxNORMAL));
+   dc->GetTextExtent(exampleText, &strW, &strH);
+   while(strH <= desiredPixelHeight && fontSize < 40) {
+     fontSize++;
+     dc->SetFont(wxFont(fontSize, wxSWISS, wxNORMAL, wxNORMAL));
+     dc->GetTextExtent(exampleText, &strW, &strH);
+   }
+   fontSize--;
+
+   labelFont = wxFont(fontSize, wxSWISS, wxNORMAL, wxNORMAL);
+
    wxColour light =
        wxSystemSettings::GetSystemColour(wxSYS_COLOUR_3DHIGHLIGHT);
    wxColour med = wxSystemSettings::GetSystemColour(wxSYS_COLOUR_3DFACE);
@@ -145,7 +188,15 @@ void AColor::Init()
    WideEnvelopePen.SetColour(110, 110, 220);
    envelopeBrush.SetColour(110, 110, 220);
    WideEnvelopePen.SetWidth( 3 );
-   
+
+   labelFlagBrush.SetColour(204, 0, 0);
+   labelUnselectedBrush.SetColour(192, 192, 192);
+   labelSelectedBrush.SetColour(148, 148, 170);
+
+   labelFlagPen.SetColour(204, 0, 0);
+   labelUnselectedPen.SetColour(192, 192, 192);
+   labelSelectedPen.SetColour(148, 148, 170);
+
    // muteBrush[1] is used when solo is on, since solo overrides mute.
 //   muteBrush[0].SetColour(110, 220, 110);
 //   muteBrush[1].SetColour(170, 180, 170);
